@@ -39,8 +39,24 @@ from xdg.IconTheme import getIconPath
 #import config
 import apps
 
+# Load an icon
+# Fall-back to default/blue if not found or name==None
 def getIcon(name, iconsize):
-    ico=getIconPath(name, iconsize)
+    # Default icon
+    idef='tasklaunch_default_application'
+
+    # If name==None then use the default icon
+    if name==None or name=='':
+	iname=idef
+    else:
+	iname=name
+
+    ico=getIconPath(iname, iconsize)
+
+    # If not found then use the default icon
+    if ico==None:
+	ico=getIconPath(idef, iconsize)
+
     ret=gtk.gdk.pixbuf_new_from_file_at_size(ico, iconsize, iconsize)
 
     return(ret)
